# This file was auto-generated by Fern from our API Definition.

import typing

ProductId = typing.Union[
    typing.Literal[
        "prod_UBhelBG3P9qpj5",
        "prod_UGc67PC09uMYuh",
        "prod_UGbRoO3FIGzPEl",
        "prod_UGbRxts1OXtMJR",
        "prod_UGbydQqsDQRq9o",
        "prod_UGbzEwRzrMBkMq",
        "prod_UGc0o1j6kjrMBR",
        "prod_TSYpaQ8bCYpBJH",
    ],
    typing.Any,
]
